@@ -4,10 +4,12 @@
 # for other package import
 from . import error_pb2
 from .error_pb2 import Error
+from . import error_reason_pb2
+from .error_reason_pb2 import ERROR_REASON_UNSPECIFIED
 
 
-def new_error(code: int, message: str,
-              reason="", localized_message="",
+def new_error(code: int, reason: int,
+              message="", localized_message="",
               metadata: dict = None) -> error_pb2.Error:
     """
 
